import { sql, type InferSelectModel } from 'drizzle-orm';
import { index, integer, primaryKey, sqliteTable, text } from 'drizzle-orm/sqlite-core';

const createdAt = integer('created_at', { mode: 'timestamp_ms' })
	.notNull()
	.default(sql`(unixepoch('subsec') * 1000)`)
	.$defaultFn(() => new Date());
const updatedAt = integer('updated_at', { mode: 'timestamp_ms' })
	.notNull()
	.default(sql`(unixepoch('subsec') * 1000)`)
	.$onUpdateFn(() => new Date());

export const entry = sqliteTable(
	'entry',
	{
		id: integer('id', { mode: 'number' }).primaryKey({ autoIncrement: true }),
		name: text('name').notNull().unique(),
		href: text('href').notNull(),
		finished: integer('finished', { mode: 'boolean' }).notNull().default(false),
		createdAt,
		updatedAt,
	}
);

type SelectEntry = InferSelectModel<typeof entry>;
